# Navigating the Architecture Executive Dashboard
### On this page
  * [Dashboard Structure](https://help.sap.com/docs/leanix/ea/navigate-architecture-executive-dashboard#dashboard-structure)
  * [Example](https://help.sap.com/docs/leanix/ea/navigate-architecture-executive-dashboard#example)


Learn how data on the dashboard is structured and how to navigate the dashboard to gain insights.
